﻿local VERSION = tonumber(("$Revision: 39146 $"):match("%d+"))

local QuestsFu = QuestsFu
local QuestsFu_Comments = QuestsFu:NewModule("Comments", "AceHook-2.1", "AceEvent-2.0")
if QuestsFu.revision < VERSION then
	QuestsFu.version = "r" .. VERSION
	QuestsFu.revision = VERSION
	QuestsFu.date = ("$Date: 2007-06-08 18:34:19 -0400 (Fri, 08 Jun 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

local tablet = AceLibrary("Tablet-2.0")
local quixote = AceLibrary("Quixote-1.0")
local dewdrop = AceLibrary("Dewdrop-2.0")

local L = AceLibrary("AceLocale-2.2"):new("QuestsFu_Comments")
L:RegisterTranslations("enUS", function() return {
	["Comments"] = true,
	["Display quest comments."] = true,
	["No comments found..."] = true,
	["LightHeaded"] = true
} end)

L:RegisterTranslations("deDE", function() return {
	["Comments"] = "Kommentare",
	["Display quest comments."] = "Anzeigen von Quest Kommentaren.",
} end)

L:RegisterTranslations("koKR", function() return {
	["Comments"] = "설명",
	["Display quest comments."] = "퀘스트 설정을 표시합니다.",
} end)

L:RegisterTranslations("esES", function() return {
	["Comments"] = "Comentarios",
	["Display quest comments."] = "Muestra los comentarios de las misiones",
} end)

L:RegisterTranslations("zhTW", function() return {
	["Comments"] = "備註",
	["Display quest comments."] = "顯示任務備註。",
	["No comments found..."] = "沒有備註...",
	["LightHeaded"] = "LightHeaded 資料庫"
} end)

function QuestsFu_Comments:OnInitialize()
	self.db = QuestsFu:AcquireDBNamespace("Comments")
	QuestsFu:RegisterDefaults("Comments", "profile", {
		lightheaded = true,
		data = {},
		strata = "HIGH",
	})
	QuestsFu.options.args.Comments = {
		name = L["Comments"],
		desc = L["Display quest comments."],
		type = "group",
		args = {
			lightheaded = {
				name = L["LightHeaded"],
				desc = L["LightHeaded"],
				type = 'toggle',
				get = function() return self.db.profile.lightheaded end,
				set = function(t) self.db.profile.lightheaded = t end,
				disabled = function() return not (LightHeaded and LightHeaded.IterateQuestComments) end
			},
			strata = {
				name=AceLibrary("AceLocale-2.2"):new("QuestsFu")["Strata"], type="text", desc=AceLibrary("AceLocale-2.2"):new("QuestsFu")["Adjust the strata of this panel (takes effect after you reload your UI)"],
				get=function() return self.db.profile.strata end,
				set=function(t) self.db.profile.strata = t end,
				validate={'BACKGROUND', 'LOW', 'MEDIUM', 'HIGH', },
				order = 1,
			},
			--This one will look a little weird on the tablet right-click menu, as it'll be duplicating native functionality.  But it's totally worth it to stop people complaining.
			lock = {
				type = 'toggle', name = AceLibrary("AceLocale-2.2"):new("QuestsFu")["Lock"],
				desc = AceLibrary("AceLocale-2.2"):new("QuestsFu")["Lock or unlock this panel"],
				disabled = function() return not tablet:IsRegistered("QuestsFu_Tracker") end,
				get = function() return tablet:IsRegistered("QuestsFu_Tracker") and tablet:IsLocked("QuestsFu_Tracker") end,
				set = function() tablet:ToggleLocked("QuestsFu_Tracker") end,
				order = 1,
			},
			toggle = {
				name = AceLibrary("AceLocale-2.2"):new("QuestsFu")["Enabled"],
				desc = AceLibrary("AceLocale-2.2"):new("QuestsFu")["Suspend/resume this module."],
				type = 'toggle',
				order = -1,
				get = function() return QuestsFu:IsModuleActive(self) end,
				set = function()
					if tablet:IsRegistered('QuestsFu_Comments') then tablet:Close('QuestsFu_Comments') end
					QuestsFu:ToggleModuleActive(self)
				end
			},
		},
	}
end

function QuestsFu_Comments:OnEnable()
	if QuestsFu:IsModuleActive('Details') then
		self:SecureHook(QuestsFu, "ShowLog")
		self:SecureHook(QuestsFu:GetModule('Details'), "UpdateQuestDetail", "Update")
	end
end

function QuestsFu_Comments:ShowLog(object, questid)
	--self.questid = questid
	if questid and LightHeaded and LightHeaded.IterateQuestComments and self.db.profile.lightheaded and QuestsFu:IsModuleActive('Details') then
		self:ScheduleEvent(self.Update, 0, self) --Schedule an event because tablet bugs out otherwise.
	end
end

function QuestsFu_Comments:Update()
	if not tablet:IsRegistered('QuestsFu_Comments') then
		local detail = QuestsFu:GetModule('Details')
		tablet:Register('QuestsFu_Comments', 'detachedData', self.db.profile.data, 'cantAttach', true, 'dontHook', true,
			'hideWhenEmpty', true, 'showTitleWhenDetached', true, 'strata', self.db.profile.strata, 'minWidth', 300,
			'menu', function() dewdrop:FeedAceOptionsTable(QuestsFu.options.args.Comments) end,
			'children', function()
				-- Much of this was taken from LightHeaded itself.
				if detail.questid and LightHeaded and LightHeaded.IterateQuestComments then
					local title, level, tag = quixote:GetQuestById(detail.questid)
					local qid,sharable,_,reqlev,stype,sname,sid,etype,ename,eid,exp,rep = LightHeaded:GetQuestInfo(title, level)
					
					tablet:SetTitle(L["Comments"])

					local cat = tablet:AddCategory('text', 'LightHeaded Info', 'columns', 1, 'wrap', true, 'child_func', LightHeaded.OnHyperlinkClick, 'child_arg1', LightHeaded, 'justify', 'CENTER')
					
					cat:AddLine('text', 'Quest ID: '..qid, 'arg2', 'lhref:external:http://www.wowhead.com/?quest='..qid)
					cat:AddLine('text', 'Shareable: '..(shareable and 'Yes' or L'No'), 'func', false)
					cat:AddLine('text', 'Level: '..level, 'func', false)
					if reqlev ~= '' then cat:AddLine('text', 'Required Level: '..reqlev, 'func', false) end
					if stype ~= '' and sname ~= '' then cat:AddLine('text', 'Starts: '..(stype=='npc' and '[' or '')..sname..(stype=='npc' and ']' or ''), 'arg2', stype=='npc' and 'lhref:npc:'..sid..':'..sname or nil) end
					if etype ~= '' and ename ~= '' then cat:AddLine('text', 'Ends: '..(etype=='npc' and '[' or '')..ename..(etype=='npc' and ']' or ''), 'arg2', etype=='npc' and 'lhref:npc:'..eid..':'..ename or nil) end
					if exp ~= '' then cat:AddLine('text', 'Experience: '..exp, 'func', false) end
					if rep ~= '' then
						-- Might want to do an inline category here with columns...
						cat:AddLine('text', 'Reputation:', 'func', false)
						for name,value in rep:gmatch("([^\031]+)\031([^\031]+)") do
							cat:AddLine('text', name .. ' - ' .. value, 'func', false)
						end
					end
					cat:AddLine('text', ' ', 'func', false) -- spacer.
					
					cat = tablet:AddCategory('text', 'LightHeaded Comments', 'columns', 1, 'wrap', true, 'child_func', LightHeaded.OnHyperlinkClick, 'child_arg1', LightHeaded, 'justify', 'CENTER')
					
					local anycomments
					for idx, qid, cid, rating, indent, parent, date, poster, comment in LightHeaded:IterateQuestComments(title, level) do
						cat:AddLine('indent', indent, 'text', ("|cFF66FF66[%s - %s - %s]|r"):format(poster, date, rating), 'func', false, 'wrap', true)
						cat:AddLine('indent', indent, 'text', comment, 'func', false, 'wrap', true)
						cat:AddLine('text', ' ', 'func', false) -- spacer.
						
						anycomments = true
					end
					
					if not anycomments then
						cat:AddLine('text', L["No comments found..."], 'func', false)
					end
					
					cat:AddLine('text', "Comments are all from WowHead", 'hasCheck', true, 'checked', true, 'checkIcon', 'Interface\\Addons\\LightHeaded\\images\\wh_icon')
				end
			end)
		tablet:Open('QuestsFu_Comments')
	end
	tablet:Refresh('QuestsFu_Comments')
end
